@@ -1,23 +1,25 @@
 /*
-    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>
     SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
 
     SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef MARKASCOMMAND_H
-#define MARKASCOMMAND_H
+#pragma once
 
 #include "commandbase.h"
 #include "messagestatus.h"
 
-#include <collection.h>
-#include <item.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 #include "akonadi-mime_export.h"
 
+#include <memory>
+
 class KJob;
-namespace Akonadi {
+namespace Akonadi
+{
 class MarkAsCommandPrivate;
 class AKONADI_MIME_EXPORT MarkAsCommand : public CommandBase
 {
@@ -28,14 +30,13 @@ public:
     ~MarkAsCommand() override;
     void execute() override;
 
-private Q_SLOTS:
+private:
     void slotCollectionFetchDone(KJob *job);
     void slotFetchDone(KJob *job);
-    void slotModifyItemDone(KJob *job);
-
-private:
+    void slotHelperDone(Result result);
+    void slotModifyItemDone();
     void markMessages();
-    MarkAsCommandPrivate *const d;
+
+    std::unique_ptr<MarkAsCommandPrivate> const d;
 };
 }
-#endif // MARKASCOMMAND_H
