@@ -6,9 +6,9 @@
 
 #include "headfetcher.h"
 
-#include <collectionfetchjob.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 
 #include "messageparts.h"
 
@@ -16,12 +16,15 @@
 #include <QDebug>
 #include <QTimer>
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 #include <KAboutData>
 #include <KLocalizedString>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 using namespace Akonadi;
 
@@ -49,7 +52,7 @@ HeadFetcher::HeadFetcher(bool multipart)
     }
 
     qDebug() << "Took:" << timer.elapsed() << "ms.";
-    QTimer::singleShot(1000, this, &HeadFetcher::stop);
+    QTimer::singleShot(1s, this, &HeadFetcher::stop);
 }
 
 void HeadFetcher::stop()
